"""
base classes for css and stylesheets packages
"""
__all__ = []
__docformat__ = 'restructuredtext'
__version__ = '0.9a5'

import xml.dom

import cssutils

  
class Base(object):
    """
    Base class for
    - css.CSSRule
    - css.Selectors
    - stylesheets.MediaList
    """
    def _checkReadonly(self):
        "raises xml.dom.NoModificationAllowedErr if rule/... is readonly"
        if hasattr(self, '_readonly') and self._readonly:
            raise xml.dom.NoModificationAllowedErr(
                u'%s is readonly.' % self.__class__)

    
    def _prepare(self, textortokens):
        """
        helper
        returns tokens (of textortokens), ttypes and logger
        """
        tokenizer = cssutils.tokenize.Tokenizer()
        ttypes, log = tokenizer.ttypes, tokenizer.log
        if isinstance(textortokens, list):
            tokens = textortokens # already tokenized
        elif isinstance(textortokens, cssutils.token.Token):
            tokens = [textortokens] # comment is a single token
        elif isinstance(textortokens, basestring):
            tokens = tokenizer.tokenize(textortokens) # already string
        else:
            if textortokens is not None:
                textortokens = unicode(textortokens)
            tokens = tokenizer.tokenize(textortokens)
        return tokens, ttypes, log            


    def _valuestr(self, t):
        """
        returns string value of t (t may be string of tokenlist)
        """
        if isinstance(t, basestring):
            return t
        else:
            return ''.join([x.value for x in t])


    # deprecated method
    def getFormatted(self, indent=4, offset=0):
        "DEPRECATED"
        import warnings
        warnings.warn('Use property cssText or mediaText of %s instead.' %
                      self.__class__, DeprecationWarning)
        return self.cssText

    pprint = getFormatted
